@@ -61,9 +61,9 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         csv_path = csv_path_list[0]
 
         try:
-            df_day = pd.read_csv(csv_path[0])
+            df_day = pd.read_csv(csv_path)
         except pd.errors.EmptyDataError:
-            raise Exception("pandas.errors.EmptyDataError (phone_lock) : " + csv_path[0])
+            raise Exception("pandas.errors.EmptyDataError (phone_lock) : " + csv_path)
 
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
